"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAnalogDevDependencies = void 0;
const semver_1 = require("semver");
const versions_1 = require("./ng_16_X/versions");
const devkit_1 = require("@nx/devkit");
const versions_2 = require("./ng_17_X/versions");
const devDependencyKeys = [
    '@analogjs/platform',
    'jsdom',
    'vite-tsconfig-paths',
    'vitest',
    '@nx/vite',
];
const getAnalogDevDependencies = (nxVersion) => {
    const escapedNxVersion = nxVersion.replace(/[~^]/, '');
    const devDependencies = getDevDependencies(escapedNxVersion);
    return { ...devDependencies };
};
exports.getAnalogDevDependencies = getAnalogDevDependencies;
const getDevDependencies = (escapedAngularVersion) => {
    // fail out for versions <15.2.0
    if ((0, semver_1.lt)(escapedAngularVersion, '16.0.0')) {
        throw new Error((0, devkit_1.stripIndents) `Angular v16.0.0 or newer is required.`);
    }
    // install 16.x deps for versions <17.0.0
    if ((0, semver_1.lt)(escapedAngularVersion, '17.0.0')) {
        return {
            '@analogjs/platform': versions_1.V16_X_ANALOG_JS_PLATFORM,
            '@nx/vite': versions_1.V16_X_NX_VITE,
            jsdom: versions_1.V16_X_JSDOM,
            'vite-tsconfig-paths': versions_1.V16_X_VITE_TSCONFIG_PATHS,
            vitest: versions_1.V16_X_VITEST,
        };
    }
    // return latest 17.x deps for versions >17.0.0
    return {
        '@analogjs/platform': versions_2.V17_X_ANALOG_JS_PLATFORM,
        '@nx/vite': versions_2.V17_X_NX_VITE,
        jsdom: versions_2.V17_X_JSDOM,
        'vite-tsconfig-paths': versions_2.V17_X_VITE_TSCONFIG_PATHS,
        vitest: versions_2.V17_X_VITEST,
    };
};
//# sourceMappingURL=dev-dependencies.js.map